@@ -12,10 +12,10 @@ import (
 	"strings"
 	"sync"
 
-	"github.com/99designs/aws-vault/v7/iso8601"
-	"github.com/99designs/aws-vault/v7/vault"
 	"github.com/aws/aws-sdk-go-v2/aws"
 	"github.com/aws/aws-sdk-go-v2/service/sts"
+	"github.com/byteness/aws-vault/v7/iso8601"
+	"github.com/byteness/aws-vault/v7/vault"
 )
 
 func writeErrorMessage(w http.ResponseWriter, msg string, statusCode int) {
