@@ -2,14 +2,10 @@ package vault
 
 import (
 	"errors"
-	"fmt"
 	"log"
-	"os"
-	"os/exec"
-	"strings"
 
-	"github.com/99designs/aws-vault/v7/prompt"
 	"github.com/aws/aws-sdk-go-v2/aws"
+	"github.com/byteness/aws-vault/v7/prompt"
 )
 
 // Mfa contains options for an MFA device
@@ -47,13 +43,5 @@ func NewMfa(config *ProfileConfig) Mfa {
 }
 
 func ProcessMfaProvider(processCmd string) (string, error) {
-	cmd := exec.Command("/bin/sh", "-c", processCmd)
-	cmd.Stderr = os.Stderr
-
-	out, err := cmd.Output()
-	if err != nil {
-		return "", fmt.Errorf("process provider: %w", err)
-	}
-
-	return strings.TrimSpace(string(out)), nil
+	return executeMFACommand(processCmd)
 }
